/* Global Styles */

body {
	margin-top: 50px;
	background: #eee;
}

a.anchor {
	display: block; position: relative; top: -50px; visibility: hidden;
}

/* ------------------------------- */

/* Wrappers */

/* ------------------------------- */

#wrapper {
    width: 100%;
}

#page-wrapper {
    padding: 0 15px 50px;
    width: 740px;
    background-color: #fff;
    margin-left: 250px;
}

#sidebar {
	position: fixed;
	width: 250px;
	top: 50px;
	bottom: 0;
	padding: 15px;
	background: #f5f5f5;
	border-right: 1px solid #ccc;
}


/* ------------------------------- */

/* Twitter typeahead.js */

/* ------------------------------- */

.twitter-typeahead {
    width: 100%;
}
.typeahead,
.tt-query,
.tt-hint {
    width: 100%;
  padding: 8px 12px;
  border: 2px solid #ccc;
  -webkit-border-radius: 8px;
     -moz-border-radius: 8px;
          border-radius: 8px;
  outline: none;
}

.typeahead {
  background-color: #fff;
}

.typeahead:focus {
  border: 2px solid #0097cf;
}

.tt-query {
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
     -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}

.tt-hint {
  color: #999
}

.tt-menu {
  width: 100%;
  margin-top: 4px;
  padding: 8px 0;
  background-color: #fff;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.2);
  -webkit-border-radius: 8px;
     -moz-border-radius: 8px;
          border-radius: 8px;
  -webkit-box-shadow: 0 5px 10px rgba(0,0,0,.2);
     -moz-box-shadow: 0 5px 10px rgba(0,0,0,.2);
          box-shadow: 0 5px 10px rgba(0,0,0,.2);
}

.tt-suggestion {
  padding: 3px 8px;
  line-height: 24px;
}

.tt-suggestion:hover {
  cursor: pointer;
  color: #fff;
  background-color: #0097cf;
}

.tt-suggestion.tt-cursor {
  color: #fff;
  background-color: #0097cf;

}

.tt-suggestion p {
  margin: 0;
}

#searchKeyword {
    width: 100%;
    margin: 0;
}

#searchKeyword .tt-menu {
  max-height: 300px;
  overflow-y: auto;
}

/* ------------------------------- */

/* Misc */

/* ------------------------------- */

.well-small ul {
	padding: 0px;
}
.table th,
.table td.pagination-centered {
	text-align: center;
}

pre {
	overflow: visible; /* Workaround for dropdown menus */
}

pre.text {
        padding: 0;
	font-size: 13px;
	color: #000;
	background: transparent;
        border: none;
        margin-bottom: 18px;
}
pre.arguments {
        font-size: 13px;
        color: #000;
        background: transparent;
}

.comment {
	color: #888;
}
small, .small {
	color: #888;
}
.level1 {
	font-size: 125%;
}
.sublevels {
	border-left: 1px solid #ccc;
	padding-left: 10px;
}
.tab {
		padding-left: 20px;
}
.keyword  {
    font-family: Menlo, Monaco, "Courier New", monospace;
    white-space: pre;
    background: #eee;
    border-top: 1px solid #fff;
    border-bottom: 1px solid #ccc;
}

.label-see-also {
	background-color: #999;
}
.label-disabled {
	background-color: #ccc;
}
h5 {
	text-decoration: underline;
}

.example-desc {
	border-bottom: 1px solid #ccc;
	margin-bottom: 18px;
}
.noheight {
	min-height: 0 !important;
}
.separator {
    margin-bottom: 18px;
}

div {
	word-wrap: break-word;
}

html, body {
	width: 100%;
	min-height: 100%:
}

.dropdown-menu > li {
	white-space: nowrap;
}
/* TEMPORARILY HACKS WHILE PRE TAGS ARE USED
-------------------------------------------------- */

h5,
.unpre,
.example-desc,
.dropdown-menu {
	font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
        white-space: normal;
}
