<a class="anchor" id="summary" name="summary"></a>
<div class="page-header">
	<h1 id="chapter-summary" data-target="summary">Summary</h1>
</div>
<div class="row">
	<div class="col-md-6">
		<% previousLevel = None %>
		% for k in chapterIndexes:
			<% chapter = chapters[k] %>
			% if chapter['title']:
				<%
					if chapter['level'] == 1:
						otag = "<b>"
						etag = "</b>"
					else:
						otag = etag = ""
				%>
				% if chapter['chapter'] == '7':
					## Quick and dirty hack to split the summary in 2 columns
					## TODO : implement a generic way split the summary
					</div><div class="col-md-6">
					<% previousLevel = None %>
				% endif
				% if otag and previousLevel:
					<br />
				% endif
				<div class="row">
					<div class="col-md-2 pagination-right noheight">${otag}<small>${chapter['chapter']}.</small>${etag}</div>
					<div class="col-md-10 noheight">
						% for tab in range(1, chapter['level']):
							<div class="tab">
						% endfor
							<a href="#${chapter['chapter']}">${otag}${chapter['title']}${etag}</a>
						% for tab in range(1, chapter['level']):
							</div>
						% endfor
					</div>
				</div>
				<% previousLevel = chapter['level'] %>
			% endif
		% endfor
	</div>
</div>
